`cloud_vm` deploys MLOps `stack` on top of Cloud provider VMs.


## Complete example with all stacks

=== "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/complete/aws-complete.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/complete/aws-complete-advanced.yaml"
    ```

## data_versioning

#### lakefs

=== "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/lakefs/aws-lakefs.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/lakefs/aws-lakefs-advanced.yaml"
    ```

## experiment_tracking

#### mlflow

=== "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/mlflow/aws-mlflow.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/mlflow/aws-mlflow-advanced.yaml"
    ```

#### wandb

=== "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/wandb/aws-wandb.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/wandb/aws-wandb-advanced.yaml"
    ```


## orchestrator

#### prefect

=== "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/prefect/aws-prefect.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/prefect/aws-prefect-advanced.yaml"
    ```

#### dagster

=== "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/dagster/aws-dagster.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/cloud_vm/dagster/aws-dagster-advanced.yaml"
    ```
